/***********************************************************************
**                                                                    **
**          /----------------------------------------------\          **
**         |  Delphes, a framework for the fast simulation  |         **
**         |       of a  generic collider experiment        |         **
**          \-------------  arXiv:0903.2225v1  ------------/          **
**                                                                    **
**                                                                    **
**   This package uses:                                               **
**   ------------------                                               **
**   ROOT: Nucl. Inst. & Meth. in Phys. Res. A389 (1997) 81-86        **
**   FastJet algorithm: Phys. Lett. B641 (2006) [hep-ph/0512210]      **
**   Hector: JINST 2:P09005 (2007) [physics.acc-ph:0707.1198v2]       **
**   FROG: [hep-ex/0901.2718v1]                                       **
**   HepMC: Comput. Phys. Commun.134 (2001) 41                        **
**                                                                    **
** ------------------------------------------------------------------ **
**                                                                    **
**   Main authors:                                                    **
**   -------------                                                    **
**                                                                    **
**                Severine Ovyn                Xavier Rouby           **
**          severine.ovyn@uclouvain.be      xavier.rouby@cern         **
**                                                                    **
**         Center for Particle Physics and Phenomenology (CP3)        **
**                Universite catholique de Louvain (UCL)              **
**                     Louvain-la-Neuve, Belgium                      **
**                                                                    **
**                      Copyright (C) 2008-2009,                      **
**                        All rights reserved.                        **
**                                                                    **
***********************************************************************/

#include "TApplication.h"
#include "FrogUtil.h"
#include "SmearUtil.h"
#include <iostream>
#include <string>
using namespace std;

int main(int argc, char *argv[])
{
  int appargc = 2;
  char *appName = "Delphes";
  char *appargv[] = {appName, "-b"};
  TApplication app(appName, &appargc, appargv);
  
  if(argc != 2 && argc != 3) {
    cout << " Usage: " << argv[0] << " input_file [N_events]" << endl;
    cout << " input_file - root file containing the events to display" << endl;
    cout << " detector_card - Datacard containing resolution variables for the detector simulation (optional) "<<endl;
    exit(1);
  }

// 1. ********** initialisation ***********
  //read the input *root file
  string inputfilename(argv[1]);
  if(inputfilename.find(".root") > inputfilename.length() ) {
    cout << "output_file should be a .root file!\n"; 
    exit(1);
  }

  //data card
  string DetDatacard("");
  if(argc==3)  DetDatacard =argv[2];

  //create output log-file name
  string forLog = inputfilename;
  string LogName = forLog.erase(forLog.find(".root"));
  LogName = LogName+"_FROG.log";



  //Smearing information
  RESOLution *DET = new RESOLution();
  DET->ReadDataCard(DetDatacard);
  DET->Logfile(LogName);

 
// 2 ************** FROG display
  FrogDisplay *FROG = new FrogDisplay(DetDatacard);
  FROG->BuildEvents(inputfilename);
  FROG->BuildGeom();

  cout << "** Exiting..." << endl;
  delete FROG;
  delete DET;
}
