/***********************************************************************
**                                                                    **
**          /----------------------------------------------\          **
**         |  Delphes, a framework for the fast simulation  |         **
**         |       of a  generic collider experiment        |         **
**          \-------------  arXiv:0903.2225v1  ------------/          **
**                                                                    **
**                                                                    **
**   This package uses:                                               **
**   ------------------                                               **
**   ROOT: Nucl. Inst. & Meth. in Phys. Res. A389 (1997) 81-86        **
**   FastJet algorithm: Phys. Lett. B641 (2006) [hep-ph/0512210]      **
**   Hector: JINST 2:P09005 (2007) [physics.acc-ph:0707.1198v2]       **
**   FROG: [hep-ex/0901.2718v1]                                       **
**   HepMC: Comput. Phys. Commun.134 (2001) 41                        **
**                                                                    **
** ------------------------------------------------------------------ **
**                                                                    **
**   Main authors:                                                    **
**   -------------                                                    **
**                                                                    **
**                Severine Ovyn                Xavier Rouby           **
**          severine.ovyn@uclouvain.be      xavier.rouby@cern         **
**                                                                    **
**         Center for Particle Physics and Phenomenology (CP3)        **
**                Universite catholique de Louvain (UCL)              **
**                     Louvain-la-Neuve, Belgium                      **
**                                                                    **
**                      Copyright (C) 2008-2009,                      **
**                        All rights reserved.                        **
**                                                                    **
***********************************************************************/

/// \file LHCO_Only.cpp
/// \brief standalone executable for running the LHCO-converter

#include "TChain.h"
#include "TFile.h"
#include "TApplication.h"
#include "LHCOConverter.h"

#include "ExRootTreeReader.h"
#include "ExRootTreeWriter.h"
#include "ExRootTreeBranch.h"
#include "BlockClasses.h"

#include <iostream>
#include <vector>
#include <fstream>
#include <iomanip>


using namespace std;


int main(int argc, char *argv[])
{
  int appargc = 2;
  char *appName= new char[20];
  char *appOpt= new char[20];
  sprintf(appName,"LHCO_Only");
  sprintf(appOpt,"-b");
  char *appargv[] = {appName,appOpt};
  TApplication app(appName, &appargc, appargv);
  delete [] appName;
  delete [] appOpt;

  if(argc != 2 && argc !=3 ) {
      cout << " Usage: " << argv[0] << " input_file [runlog_file] " << endl;
      cout << " input_file - file in Delphes root format," << endl;
      cout << " [runlog_file] - the corresponding log file (optional) "<<endl;
      exit(1);
  }

 string rootfile = argv[1];
 string logfile;
 if(argc ==3) logfile=argv[2];

 LHCOConverter converter(rootfile,logfile);
 converter.CopyRunLogFile();
 converter.ConvertExRootAnalysisToLHCO();
  
  cout << "** Exiting..." << endl;
 
}

