#ifndef ANALYSIS_EX_H
#define ANALYSIS_EX_H

/***********************************************************************
**                                                                    **
**          /----------------------------------------------\          **
**         |  Delphes, a framework for the fast simulation  |         **
**         |       of a  generic collider experiment        |         **
**          \-------------  arXiv:0903.2225v1  ------------/          **
**                                                                    **
**                                                                    **
**   This package uses:                                               **
**   ------------------                                               **
**   ROOT: Nucl. Inst. & Meth. in Phys. Res. A389 (1997) 81-86        **
**   FastJet algorithm: Phys. Lett. B641 (2006) [hep-ph/0512210]      **
**   Hector: JINST 2:P09005 (2007) [physics.acc-ph:0707.1198v2]       **
**   FROG: [hep-ex/0901.2718v1]                                       **
**   HepMC: Comput. Phys. Commun.134 (2001) 41                        **
**                                                                    **
** ------------------------------------------------------------------ **
**                                                                    **
**   Main authors:                                                    **
**   -------------                                                    **
**                                                                    **
**                Severine Ovyn                Xavier Rouby           **
**          severine.ovyn@uclouvain.be      xavier.rouby@cern         **
**                                                                    **
**         Center for Particle Physics and Phenomenology (CP3)        **
**                Universite catholique de Louvain (UCL)              **
**                     Louvain-la-Neuve, Belgium                      **
**                                                                    **
**                      Copyright (C) 2008-2009,                      **
**                        All rights reserved.                        **
**                                                                    **
***********************************************************************/

#include "TObject.h"
#include "TClonesArray.h"
#include <string>

#include "Utilities/ExRootAnalysis/interface/ExRootTreeReader.h"
#include "Utilities/ExRootAnalysis/interface/ExRootTreeWriter.h"
#include "Utilities/ExRootAnalysis/interface/ExRootTreeBranch.h"
#include "Utilities/ExRootAnalysis/interface/TSimpleArray.h"
#include "Utilities/ExRootAnalysis/interface/BlockClasses.h"

using namespace std;

class Analysis_Ex 
{
public :

  Analysis_Ex(string CardWithCuts,string LogName);  
  ~Analysis_Ex();
  
  void Run(ExRootTreeReader *treeReaderGen, ExRootTreeReader *treeReaderRec, ExRootTreeReader *treeReaderTrig, ExRootTreeWriter *treeWriter);//Analyze de l'event
  void WriteOutput(string LogName);

private :

  int total, cut_trig,cut_1,cut_2;

  //******** Thresholds definition ***********
  float INV_MASS_LL;
  float PT_ELEC,PT_MUON;

  TSimpleArray<TRootElectron> SubArrayEl(const TClonesArray *ELEC,float pt);
  TSimpleArray<TRootMuon> SubArrayMu(const TClonesArray *MUON,float pt);

};

//------------------------------------------------------------------------------

class TRootInvm: public TObject
{
public:

Float_t M;

  ClassDef(TRootInvm, 1)
};


#endif
