
/** \class ExRootTreeBranch
*
*  Class handling output ROOT tree branch
*
*  $Date: 2009-02-02 11:32:01 $
*  $Revision: 1.2 $
*
*
*  \author S. Ovyn - UCL, Louvain-la-Neuve
*
*/

#include "ExRootTreeBranch.h"
#include "TTree.h"
#include "TClonesArray.h"

//------------------------------------------------------------------------------

ExRootTreeBranch::ExRootTreeBranch(const TString &name, TClass *cl, TTree *tree) :
  fSize(0), fCapacity(1), fData(0)
{
  cl->IgnoreTObjectStreamer();
  fData = new TClonesArray(cl, fCapacity);

  if(fData)
  {
    fData->ExpandCreateFast(fCapacity);
    fData->Clear();
    tree->Branch(name, &fData, 64000);
    tree->Branch(name + "_size", &fSize, name + "_size/I");
  }
  else
  {
    throw MemoryAllocationExeption();
  }
}

//------------------------------------------------------------------------------

ExRootTreeBranch::~ExRootTreeBranch()
{
  if(fData) delete fData;
}

//------------------------------------------------------------------------------

TObject *ExRootTreeBranch::NewEntry()
{
  if(!fData) return 0;

  if(fSize >= fCapacity)
  {
    Int_t entry;

    if(fCapacity < 10) fCapacity = 10;
    else if(fCapacity < 30) fCapacity = 30;
    else if(fCapacity < 100) fCapacity = 100;
    else if(fCapacity < 250) fCapacity = 250;
    else fCapacity *= 2;

    fData->ExpandCreateFast(fCapacity);

    fData->Clear();
    for(entry = 0; entry < fSize; ++entry) fData->AddrAt(entry);
  }
  
  return fData->AddrAt(fSize++);
}

//------------------------------------------------------------------------------

void ExRootTreeBranch::Clear()
{
  fSize = 0;
  if(fData) fData->Clear();
}

//------------------------------------------------------------------------------

