#ifndef _DATACONVERTER_H_
#define _DATACONVERTER_H_

/***********************************************************************
**                                                                    **
**          /----------------------------------------------\          **
**         |  Delphes, a framework for the fast simulation  |         **
**         |       of a  generic collider experiment        |         **
**          \-------------  arXiv:0903.2225v1  ------------/          **
**                                                                    **
**                                                                    **
**   This package uses:                                               **
**   ------------------                                               **
**   ROOT: Nucl. Inst. & Meth. in Phys. Res. A389 (1997) 81-86        **
**   FastJet algorithm: Phys. Lett. B641 (2006) [hep-ph/0512210]      **
**   Hector: JINST 2:P09005 (2007) [physics.acc-ph:0707.1198v2]       **
**   FROG: [hep-ex/0901.2718v1]                                       **
**   HepMC: Comput. Phys. Commun.134 (2001) 41                        **
**                                                                    **
** ------------------------------------------------------------------ **
**                                                                    **
**   Main authors:                                                    **
**   -------------                                                    **
**                                                                    **
**                Severine Ovyn                Xavier Rouby           **
**          severine.ovyn@uclouvain.be      xavier.rouby@cern         **
**                                                                    **
**         Center for Particle Physics and Phenomenology (CP3)        **
**                Universite catholique de Louvain (UCL)              **
**                     Louvain-la-Neuve, Belgium                      **
**                                                                    **
**                      Copyright (C) 2008-2009,                      **
**                        All rights reserved.                        **
**                                                                    **
***********************************************************************/

/// \file DataConverter
/// \brief DataConverter class, as mother of LHEFConverter, STDHEPConverter, ...

#include <string>

#include "PdgParticle.h"
#include "Utilities/ExRootAnalysis/interface/ExRootTreeBranch.h"
#include "Utilities/ExRootAnalysis/interface/LHEF.h"

using namespace std;

class DataConverter
{
public:

  DataConverter() : Nevt(-1) {};
  DataConverter(const PdgTable& table, const int &N) : Nevt(N), pdg_table(table) {};
  virtual ~DataConverter() {};

protected:
  int Nevt; // number of events to read; -1 means "all of them"

public: 
  PdgTable pdg_table;   // table of particles from PDG
};

#endif
