#ifndef _FROGUTIL_H_
#define _FROGUTIL_H_

/***********************************************************************
**                                                                    **
**          /----------------------------------------------\          **
**         |  Delphes, a framework for the fast simulation  |         **
**         |       of a  generic collider experiment        |         **
**          \-------------  arXiv:0903.2225v1  ------------/          **
**                                                                    **
**                                                                    **
**   This package uses:                                               **
**   ------------------                                               **
**   ROOT: Nucl. Inst. & Meth. in Phys. Res. A389 (1997) 81-86        **
**   FastJet algorithm: Phys. Lett. B641 (2006) [hep-ph/0512210]      **
**   Hector: JINST 2:P09005 (2007) [physics.acc-ph:0707.1198v2]       **
**   FROG: [hep-ex/0901.2718v1]                                       **
**   HepMC: Comput. Phys. Commun.134 (2001) 41                        **
**                                                                    **
** ------------------------------------------------------------------ **
**                                                                    **
**   Main authors:                                                    **
**   -------------                                                    **
**                                                                    **
**                Severine Ovyn                Xavier Rouby           **
**          severine.ovyn@uclouvain.be      xavier.rouby@cern         **
**                                                                    **
**         Center for Particle Physics and Phenomenology (CP3)        **
**                Universite catholique de Louvain (UCL)              **
**                     Louvain-la-Neuve, Belgium                      **
**                                                                    **
**                      Copyright (C) 2008-2009,                      **
**                        All rights reserved.                        **
**                                                                    **
***********************************************************************/


/// \file FrogUtil.h
/// \brief FrogDisplay class

#include "SmearUtil.h"

#include "BaseColl.h"
#include "BaseColl_Id.h"
#include "BaseColl_Name.h"
#include "Base.h"
#include "CMS_Geom_Calo.h"
#include "CMS_Geom_Tracking.h"
#include "Event.h"
#include "Event_Beam.h"
#include "Event_CaloHit.h"
#include "Event_CaloTower.h"
#include "Event_Candidate.h"
#include "Event_Cluster_SiStrip.h"
#include "Event_dEdX.h"
#include "Event_Electron.h"
#include "Event_Hit.h"
#include "Event_Jet.h"
#include "Event_MET.h"
#include "Event_Photon.h"
#include "Event_Segment.h"
#include "Event_Sim_Hit.h"
#include "Event_Sim_Particle.h"
#include "Event_Sim_Track.h"
#include "Event_Sim_Vertex.h"
#include "Event_SingleStrip.h"
#include "Event_Track.h"
#include "Event_Vertex.h"
#include "Prim_Circle.h"
#include "Prim_Cube.h"
#include "Prim_CustomCube.h"
#include "Prim_CustomSurface.h"
#include "Prim_Cylinder.h"
#include "Prim_Disc.h"
#include "Prim_FiveSidedPolygon.h"
#include "Prim_Line.h"
#include "Prim_PartialSphere.h"
#include "Prim_Rectangle.h"
#include "Prim_Sphere.h"
#include "Prim_Tube.h"

#define EVTID_SIM				21000000

using namespace FROG;

using namespace std;
class FrogDisplay {

 public:
   /// Constructor
   FrogDisplay();
   FrogDisplay(const string& DetDatacard);
   FrogDisplay(const RESOLution* DetDatacard);
   FrogDisplay(const FrogDisplay& frog);
   FrogDisplay& operator=(const FrogDisplay& frog);
   ~FrogDisplay() {delete DET;}

  void BuildEvents(const string& outputfilename);
  void BuildGeom();

 private:
   RESOLution *DET;
   unsigned int nEntryFrog;

};

#endif
