#ifndef _LHCOCONVERTER_H_
#define _LHCOCONVERTER_H_

/***********************************************************************
**                                                                    **
**          /----------------------------------------------\          **
**         |  Delphes, a framework for the fast simulation  |         **
**         |       of a  generic collider experiment        |         **
**          \-------------  arXiv:0903.2225v1  ------------/          **
**                                                                    **
**                                                                    **
**   This package uses:                                               **
**   ------------------                                               **
**   ROOT: Nucl. Inst. & Meth. in Phys. Res. A389 (1997) 81-86        **
**   FastJet algorithm: Phys. Lett. B641 (2006) [hep-ph/0512210]      **
**   Hector: JINST 2:P09005 (2007) [physics.acc-ph:0707.1198v2]       **
**   FROG: [hep-ex/0901.2718v1]                                       **
**   HepMC: Comput. Phys. Commun.134 (2001) 41                        **
**                                                                    **
** ------------------------------------------------------------------ **
**                                                                    **
**   Main authors:                                                    **
**   -------------                                                    **
**                                                                    **
**                Severine Ovyn                Xavier Rouby           **
**          severine.ovyn@uclouvain.be      xavier.rouby@cern         **
**                                                                    **
**         Center for Particle Physics and Phenomenology (CP3)        **
**                Universite catholique de Louvain (UCL)              **
**                     Louvain-la-Neuve, Belgium                      **
**                                                                    **
**                      Copyright (C) 2008-2009,                      **
**                        All rights reserved.                        **
**                                                                    **
***********************************************************************/

/// \file LHCOConverter
/// \brief Converter from ExRootAnalysis to LHCO files
#include <sstream>
#include <string>
using namespace std;

class TClonesArray;

enum {lhcoPhotonID=0,  lhcoElectronID, lhcoMuonID, lhcoTauJetID, lhcoJetID, lhcoETmisID=6};

class LHCOConverter {
public:

  explicit LHCOConverter(const string& inputroot, const string& inputlog);
  ~LHCOConverter() {};

  void CopyRunLogFile();
  void ConvertExRootAnalysisToLHCO();

private:
  //ostringstream BranchReader(const TClonesArray*, unsigned int&, unsigned short int ) const; // put it as a operator<<
  void BranchReader(const TClonesArray*, unsigned int&, unsigned short int ) const;
  void BranchReaderETmis(const TClonesArray* branch, unsigned int& line) const;  
  void BranchReaderMuon(const TClonesArray* branchMuon, const TClonesArray* branchJet, unsigned int& line) const;

  const string inputfilename_;
  string inputlogname_;
  string outputfilename_;
  bool valid_;
};

#endif
