#ifndef TreeClasses_h
#define TreeClasses_h

/***********************************************************************
**                                                                    **
**          /----------------------------------------------\          **
**         |  Delphes, a framework for the fast simulation  |         **
**         |       of a  generic collider experiment        |         **
**          \-------------  arXiv:0903.2225v1  ------------/          **
**                                                                    **
**                                                                    **
**   This package uses:                                               **
**   ------------------                                               **
**   ROOT: Nucl. Inst. & Meth. in Phys. Res. A389 (1997) 81-86        **
**   FastJet algorithm: Phys. Lett. B641 (2006) [hep-ph/0512210]      **
**   Hector: JINST 2:P09005 (2007) [physics.acc-ph:0707.1198v2]       **
**   FROG: [hep-ex/0901.2718v1]                                       **
**   HepMC: Comput. Phys. Commun.134 (2001) 41                        **
**                                                                    **
** ------------------------------------------------------------------ **
**                                                                    **
**   Main authors:                                                    **
**   -------------                                                    **
**                                                                    **
**                Severine Ovyn                Xavier Rouby           **
**          severine.ovyn@uclouvain.be      xavier.rouby@cern         **
**                                                                    **
**         Center for Particle Physics and Phenomenology (CP3)        **
**                Universite catholique de Louvain (UCL)              **
**                     Louvain-la-Neuve, Belgium                      **
**                                                                    **
**                      Copyright (C) 2008-2009,                      **
**                        All rights reserved.                        **
**                                                                    **
***********************************************************************/


#include "TObject.h"
#include "Utilities/ExRootAnalysis/interface/BlockCompare.h"
#include "Utilities/ExRootAnalysis/interface/BlockClasses.h"

//------------------------------------------------------------------------------

class RESOLJET : public TSortableObject
{
public:
  float SmearedPT;
  float PT;
  float E;          // generator E
  float dE;         // (recoE-genE)/genE
  float dE2;        // ( (recoE-genE)/ genE )^2
  float Eta;	    // generator-level eta
  float dE_reco;    // (recoE-genE)/recoE
  float dE2_reco;   // ( (recoE-genE)/ recoE )^2


  static TCompare *fgCompare; //!
  const TCompare *GetCompare() const { return fgCompare; }


 ClassDef(RESOLJET,1)

};


//------------------------------------------------------------------------------

class RESOLELEC : public TSortableObject
{
public:
Float_t E;
Float_t SmearedE;

  static TCompare *fgCompare; //!
  const TCompare *GetCompare() const { return fgCompare; }


 ClassDef(RESOLELEC,1)

};

//------------------------------------------------------------------------------

class RESOLMUON : public TSortableObject
{
public:
Float_t OverSmearedPT;
Float_t OverPT;

  static TCompare *fgCompare; //!
  const TCompare *GetCompare() const { return fgCompare; }


 ClassDef(RESOLMUON,1)

};

//------------------------------------------------------------------------------

class TAUHAD : public TSortableObject
{
public:
Float_t EnergieCen;
Float_t NumTrack;

  static TCompare *fgCompare; //!
  const TCompare *GetCompare() const { return fgCompare; }


 ClassDef(TAUHAD,1)

};

//---------------------------------------------

class ETMIS : public TSortableObject
{
public:
Float_t Et;
Float_t SEt;
Float_t Ex;
Float_t EtSmeare;
Float_t ExSmeare;

 static TCompare *fgCompare; //!
  const TCompare *GetCompare() const { return fgCompare; }


 ClassDef(ETMIS,1)

};


//------------------------------------------------------------------------------

class RECZ : public TObject
{
public:

Float_t M;

  ClassDef(RECZ,1)
};

//------------------------------------------------------------------------------

class HWWT : public TObject
{
public:

Float_t DeltaPhi;
Float_t DeltaEta;
Float_t M;
  ClassDef(HWWT,1)
};


//------------------------------------------------------------------------------

class RECW : public TObject
{
public:

Float_t M;

  ClassDef(RECW,1)
};

//------------------------------------------------------------------------------

class RECH : public TObject
{
public:

Float_t M;

  ClassDef(RECH,1)
};


class TRACKOF : public TObject
{
public:

Float_t SUM;
Float_t NUM;


  ClassDef(TRACKOF,1)
};


//------------------------------------------------------------------------------

class TRACK : public TObject
{
public:

Float_t SUM;
Float_t NUM;


  ClassDef(TRACK,1)
};

class TRACKhbb : public TObject
{
public:

Float_t SUM;
Float_t NUM;


  ClassDef(TRACKhbb,1)
};


//------------------------------------------------------------------------------

class PTMIS : public TObject
{
public:

Float_t PT;

  ClassDef(PTMIS,1)
};


//------------------------------------------------------------------------------

class ASYM: public TObject
{
public:

Float_t Val;

  ClassDef(ASYM, 1)
};

//------------------------------------------------------------------------------

class HFENERGY : public TObject
{
public:

Float_t E;

  ClassDef(HFENERGY,1)
};

//------------------------------------------------------------------------------

class NUMLEPT : public TObject
{
public:

Int_t Num;

  ClassDef(NUMLEPT,1)
};

//------------------------------------------------------------------------------
class LEPT1: public TObject
{
public:

Float_t lept1PT;
Float_t lept1ETA;

  ClassDef(LEPT1, 1)
};

//------------------------------------------------------------------------------

class LEPT2: public TObject
{
public:

Float_t lept2PT;
Float_t lept2ETA;

  ClassDef(LEPT2, 1)
};

//------------------------------------------------------------------------------

class LEPT3: public TObject
{
public:

Float_t lept3PT;
Float_t lept3ETA;

  ClassDef(LEPT3, 1)
};


//------------------------------------------------------------------------------

class NUMBJET: public TObject
{
public:

Int_t Num;

  ClassDef(NUMBJET,1)
};

//------------------------------------------------------------------------------

class BJET1: public TObject
{
public:

Float_t bjet1PT;
Float_t bjet1ETA;

  ClassDef(BJET1, 1)
};

//------------------------------------------------------------------------------

class BJET2: public TObject
{
public:

Float_t bjet2PT;
Float_t bjet2ETA;

  ClassDef(BJET2, 1)
};
//------------------------------------------------------------------------------

class BJET3: public TObject
{
public:

Float_t bjet3PT;
Float_t bjet3ETA;

  ClassDef(BJET3, 1)
};

//------------------------------------------------------------------------------

class JET1: public TObject
{
public:

Float_t jet1PT;
Float_t jet1ETA;

  ClassDef(JET1, 1)
};

//------------------------------------------------------------------------------

class JET2: public TObject
{
public:

Float_t jet2PT;
Float_t jet2ETA;

  ClassDef(JET2, 1)
};

//------------------------------------------------------------------------------

class JET3: public TObject
{
public:

Float_t jet3PT;
Float_t jet3ETA;

  ClassDef(JET3, 1)
};

//------------------------------------------------------------------------------

class VSUM: public TObject
{
public:

Float_t Scalar;
Float_t Vector;
Float_t VectorEta;
Float_t ScalarJet;

  ClassDef(VSUM, 1)
};


//------------------------------------------------------------------------------

class NUMJET : public TObject
{
public:

Int_t Num;

  ClassDef(NUMJET,1)
};


//------------------------------------------------------------------------------

class TWOLEPTON : public TObject
{
public:

Float_t INV;
Float_t PHISEP;

ClassDef(TWOLEPTON,1)
};


class ETASEP : public TObject
{
public:

Float_t Val;

  ClassDef(ETASEP,1)
};


#endif /* TreeClasses_h */
