#ifndef _VERYFORWARD_H_
#define _VERYFORWARD_H_

/***********************************************************************
**                                                                    **
**          /----------------------------------------------\          **
**         |  Delphes, a framework for the fast simulation  |         **
**         |       of a  generic collider experiment        |         **
**          \-------------  arXiv:0903.2225v1  ------------/          **
**                                                                    **
**                                                                    **
**   This package uses:                                               **
**   ------------------                                               **
**   ROOT: Nucl. Inst. & Meth. in Phys. Res. A389 (1997) 81-86        **
**   FastJet algorithm: Phys. Lett. B641 (2006) [hep-ph/0512210]      **
**   Hector: JINST 2:P09005 (2007) [physics.acc-ph:0707.1198v2]       **
**   FROG: [hep-ex/0901.2718v1]                                       **
**   HepMC: Comput. Phys. Commun.134 (2001) 41                        **
**                                                                    **
** ------------------------------------------------------------------ **
**                                                                    **
**   Main authors:                                                    **
**   -------------                                                    **
**                                                                    **
**                Severine Ovyn                Xavier Rouby           **
**          severine.ovyn@uclouvain.be      xavier.rouby@cern         **
**                                                                    **
**         Center for Particle Physics and Phenomenology (CP3)        **
**                Universite catholique de Louvain (UCL)              **
**                     Louvain-la-Neuve, Belgium                      **
**                                                                    **
**                      Copyright (C) 2008-2009,                      **
**                        All rights reserved.                        **
**                                                                    **
***********************************************************************/

#include <vector>

#include "SmearUtil.h"
#include "BlockClasses.h"
#include "ExRootTreeBranch.h"
#include "ExRootTreeWriter.h"
#include "H_BeamParticle.h"
#include "H_BeamLine.h"
#include "PhysicsTower.hh"

using namespace std;

class VeryForward {

 public:
  /// Constructor
   VeryForward();
   VeryForward(const string& DetDatacard);
   VeryForward(const RESOLution * DetDatacard);
   VeryForward(const VeryForward& vf);
   VeryForward& operator=(const VeryForward& vf);
   void init();
   ~VeryForward() {delete DET; delete beamline1; delete beamline2;};

   void ZDC(ExRootTreeWriter *treeWriter,ExRootTreeBranch *branchZDC,TRootGenParticle *particle);
   void RomanPots(ExRootTreeWriter *treeWriter, ExRootTreeBranch *branchRP220,ExRootTreeBranch *branchFP420,TRootGenParticle *particle) ;


 private:
   RESOLution *DET;
   float d_max;
   H_BeamLine* beamline1;
   H_BeamLine* beamline2;
   bool rel_energy;
   int kickers;
   static unsigned int counter;

   float time_of_flight(TRootGenParticle *particle, const float detector_s, const float detector_etamin, const float detector_t_resolution);

};
#endif
