/***********************************************************************
**                                                                    **
**          /----------------------------------------------\          **
**         |  Delphes, a framework for the fast simulation  |         **
**         |       of a  generic collider experiment        |         **
**          \-------------  arXiv:0903.2225v1  ------------/          **
**                                                                    **
**                                                                    **
**   This package uses:                                               **
**   ------------------                                               **
**   ROOT: Nucl. Inst. & Meth. in Phys. Res. A389 (1997) 81-86        **
**   FastJet algorithm: Phys. Lett. B641 (2006) [hep-ph/0512210]      **
**   Hector: JINST 2:P09005 (2007) [physics.acc-ph:0707.1198v2]       **
**   FROG: [hep-ex/0901.2718v1]                                       **
**   HepMC: Comput. Phys. Commun.134 (2001) 41                        **
**                                                                    **
** ------------------------------------------------------------------ **
**                                                                    **
**   Main authors:                                                    **
**   -------------                                                    **
**                                                                    **
**                Severine Ovyn                Xavier Rouby           **
**          severine.ovyn@uclouvain.be      xavier.rouby@cern         **
**                                                                    **
**         Center for Particle Physics and Phenomenology (CP3)        **
**                Universite catholique de Louvain (UCL)              **
**                     Louvain-la-Neuve, Belgium                      **
**                                                                    **
**                      Copyright (C) 2008-2009,                      **
**                        All rights reserved.                        **
**                                                                    **
***********************************************************************/

#include "TROOT.h"
#include "TFile.h"
#include "TTree.h"
#include "TCanvas.h"
#include "TProfile.h"
#include "TF1.h"
#include "TGraph.h"
#include "TMultiGraph.h"
#include "TGraphErrors.h"
#include "TLegend.h"

#include "interface/FuncDef.h"

void JetResol()
{
  setTDRStyle();
  gROOT->Reset();
  
  TFile *f1 = new TFile("JET2.root","read");
  if(!f1->IsOpen()) { cout << "could not open "<< f1->GetName() << ". Exiting..." << endl; return;}
  if(!f1->FindKey("Analysis")) { cout << "Bad input file, could not find the \"Analysis\" tree. Exiting..." << endl; return;}
  TTree *Analyze = (TTree*)f1->Get("Analysis");
  
  const Int_t numBin=16;
  double bins[numBin]={0,10,20,30,40,50,60,70,80,100,120,140,180,220,300,1200};
  TProfile *ETSoverET = new TProfile("ETSoverET","Jet resolution: E_{T}^{rec}/E_{T}^{mc}",(numBin-1),bins,-10,10);
  
  double rms[numBin];
  double mean[numBin];
  
  TCanvas *c1 = new TCanvas("c1","JET resol",0,0,1000,650);
  c1->cd(); int frame=0;
  c1->Divide(6,2);
  
  float x[numBin-1];
  float y[numBin-1];
  float ex[numBin-1];
  float ey[numBin-1];
  float erec_over_etruth[numBin-1];
  
  float finval=0;//valeur a remplir puis a fitter
  
  for ( int i=0; i<(numBin-1); i++)  // première bin : i ==1 et pas i == 0
    {
      TAxis *xaxis = ETSoverET->GetXaxis();
      float binCenter = xaxis->GetBinCenter(i+1);
      int binMin = (int)xaxis->GetBinLowEdge(i+1);
      int binMax = (int)xaxis->GetBinUpEdge(i+1);
      char tempMin[500];
      if(i==0)binMin=5;
      sprintf(tempMin,"JetPTResol.PT > %d",binMin);
      string mystringMin(tempMin);
      char tempMax[500];
      sprintf(tempMax,"JetPTResol.PT < %d",binMax);
      string mystringMax(tempMax);
      char tempName[500];
      sprintf(tempName,"(JetPTResol.SmearedPT)>>hETSoverET%d",i);
      string mystringName(tempName);
      
      c1->cd(++frame);
      GaussValues(Analyze,tempName,rms[i],mean[i],mystringMin,mystringMax);
      x[i]=binCenter;
      finval=rms[i]/mean[i];
      y[i]=(finval*100);
      ex[i]=0;
      ey[i]=0;
      erec_over_etruth[i]=mean[i]+1;
    }
 

  TCanvas *c3 = new TCanvas("c3","JET linearity",100,100,600,450);
  c3->cd();
  //for(int i=0; i<numBin-1; i++) cout << x[i] << "\t\t" << erec_over_etruth[i] << endl;
  TGraph *linearity = new TGraph(numBin-1,x,erec_over_etruth);
  linearity->Draw("AP");
  linearity->SetTitle("");
  linearity->GetXaxis()->SetTitle("E^{Truth} [GeV]");
  linearity->GetYaxis()->SetTitle("<E^{Reco}/E^{Truth}>");
  linearity->GetXaxis()->SetRangeUser(30,1000);
  linearity->SetMinimum(0.85);
  linearity->SetMaximum(1.20);
  gPad->SetLogx();

 
  TCanvas *c2 = new TCanvas("c2","JET resol",100,100,600,450);
  c2->cd();
  
  TF1 *fitfun = new TF1("user","sqrt(pow([0]/x,2)+pow([1]/sqrt(x),2)+pow([2],2))",10,800);
  TF1 *fitfunCMS = new TF1("userCMS","sqrt(pow(1.05*100/sqrt(x),2)+pow(0.06*100,2)+pow(0*100/x,2))",10,800);
  //TF1 *fitfunCMS = new TF1("userCMS","sqrt(pow(1.17*100/sqrt(x),2)+pow(0.039*100,2))",10,800);
  
  TGraph *gr11 = new TGraph((numBin-1),x,y);
  gr11->Draw("AP");
  gr11->SetTitle("");
  gr11->GetXaxis()->SetTitle("E_{T}^{MC} [GeV]");
  gr11->GetYaxis()->SetRangeUser(0,50);
  gr11->GetYaxis()->SetTitle("#sigma(E_{T}^{rec}/E_{T}^{MC})_{fit}/<E_{T}^{rec}/E_{T}^{MC}>_{fit}");
  
  Double_t* params = fitfun->GetParameters();

  fitfun->SetLineColor(6);
  gr11->Fit("user","QR");
  gr11->Fit("user","QR");
  gr11->Fit("user","QR");
  gr11->Fit("user","QR");
  char tempResol[100];
  sprintf(tempResol,"Delphes resolution: #frac{#sigma(E_{T}^{rec}/E_{T}^{MC})}{<E_{T}^{rec}/E_{T}^{MC}>} = #frac{%f}{#sqrt{E_{T}^{MC}}} #oplus %f",params[1],params[2]);
 char tempResol2[100];
  sprintf(tempResol2,"sqrt(pow(%f/sqrt(x),2)+pow(%f,2))",params[1],params[2]);


  TF1 *fitfunDelphes = new TF1("userDelphes",tempResol2,7,1000);
  fitfunDelphes->SetLineColor(6);
  fitfunDelphes->Draw("same");

  //CMS values
  fitfunCMS->SetLineColor(9);
  fitfunCMS->Draw("same");

  TPaveText *events = MakeTPave(0.2,0.75,0.35,0.8,"Events: pp #rightarrow gg ");
  events->Draw();

  TPaveText *Delphes = MakeTPave(0.2,0.15,0.35,0.2,"MG/ME + Delphes");
  Delphes->Draw();

  TLegend *legend = new TLegend(0.2,0.6,0.9,0.85,NULL,"NDC");
  legend->AddEntry(fitfunCMS,"CMS resolution","l");
  legend->AddEntry(fitfunDelphes,tempResol,"l");
  legend->SetFillColor(10);
  legend->SetBorderSize(0);
  legend->Draw();

  delete fitfun;
}

void ElecResol()
{
  
  setTDRStyle();
  gROOT->Reset();
  
  TFile *f1 = new TFile("ETMIS2.root","read");
  if(!f1->IsOpen()) { cout << "could not open "<< f1->GetName() << ". Exiting..." << endl; return;}
  if(!f1->FindKey("Analysis")) { cout << "Bad input file, could not find the \"Analysis\" tree. Exiting..." << endl; return;}
  TTree *Analyze = (TTree*)f1->Get("Analysis");
  
  const Int_t numBin=11;
  double bins[numBin]={0,10,20,30,40,50,60,70,80,100,120};
  TProfile *ETSminusET = new TProfile("ETSminusET","Electron resolution: E_{T}^{rec}/E_{T}^{mc}",(numBin-1),bins,-10,10);
  
  double rms[numBin];
  double mean[numBin];
  
  TCanvas *c3 = new TCanvas("c3","ELEC resol",0,0,1000,650);
  c3->cd(); int frame=0;
  c3->Divide(6,2);
  
  float x[numBin-1];
  float y[numBin-1];
  float ex[numBin-1];
  float ey[numBin-1];
  
  float finval=0;//valeur a remplir puis a fitter
  
  for ( int i=0; i<(numBin-1); i++)  // première bin : i ==1 et pas i == 0
    {
      TAxis *xaxis = ETSminusET->GetXaxis();
      float binCenter = xaxis->GetBinCenter(i+1);
      int binMin = (int)xaxis->GetBinLowEdge(i+1);
      int binMax = (int)xaxis->GetBinUpEdge(i+1);
      char tempMin[500];
      if(i==0)binMin=5;
      sprintf(tempMin,"ElecEResol.E > %d",binMin);
      string mystringMin(tempMin);
      char tempMax[500];
      sprintf(tempMax,"ElecEResol.E < %d",binMax);
      string mystringMax(tempMax);
      char tempName[500];
      sprintf(tempName,"(ElecEResol.E-ElecEResol.SmearedE)>>hETSoverET%d",i);
      string mystringName(tempName);
      
      c3->cd(++frame);
      GaussValuesElec(Analyze,tempName,rms[i],mean[i],mystringMin,mystringMax);
      //GaussValues(Analyze,tempName,rms[i],mean[i],mystringMin,mystringMax);
      x[i]=binCenter;
      finval=rms[i]/binCenter;
      y[i]=(finval*100);
      ex[i]=0;
      ey[i]=0;
    }
  
  TCanvas *c4 = new TCanvas("c4","ELEC resol",100,100,600,450);
  c4->cd();
  
  TF1 *fitfun = new TF1("user","sqrt(pow([0],2)+pow([1]/sqrt(x),2)+pow([2]/x,2))",1,400);
  
  TGraphErrors *gr11 = new TGraphErrors((numBin-1),x,y,ex,ey);
  gr11->Draw("AP");
  gr11->SetTitle("");
  gr11->GetXaxis()->SetTitle("E [GeV]");
  gr11->GetYaxis()->SetRangeUser(0,5);
  gr11->GetYaxis()->SetTitle("#sigma/E");
  
  Double_t* params = fitfun->GetParameters();
  
  gr11->Fit("user","QR");
  gr11->Fit("user","QRI");
  gr11->Fit("user","QRI");
  gr11->Fit("user","QRI");
  char tempResol[500];
  sprintf(tempResol,"#frac{#sigma}{E} = #frac{%f}{#sqrt{E}} #oplus #frac{%f}{E} #oplus %f",params[1]/100,params[2]/100,params[0]/100);
  
  TPaveText *leg1 = MakeTPave(0.4,0.6,0.8,0.65,tempResol);
  leg1->Draw();
  
  TPaveText *Delphes = MakeTPave(0.2,0.15,0.35,0.2,"MG/ME + Delphes");
  Delphes->Draw();
  
  TPaveText *events = MakeTPave(0.2,0.75,0.35,0.8,"Events: WHq'#rightarrow W#tau#tauq'#rightarrowjjl#tauq', m_{H}=150 GeV ");
  events->Draw();
  
  delete fitfun;
}

void TauJetInfo()
{
  
  setTDRStyle();
  gROOT->Reset();
  
  TFile *f1 = new TFile("TAUJET2.root","read");
  if(!f1->IsOpen()) { cout << "could not open "<< f1->GetName() << ". Exiting..." << endl; return;}
  if(!f1->FindKey("Analysis")) { cout << "Bad input file, could not find the \"Analysis\" tree. Exiting..." << endl; return;}
  TTree *Analyze = (TTree*)f1->Get("Analysis");
  
  TCanvas *ct1 = new TCanvas("ct1","Tau information",100,100,600,450);
  ct1->cd(); 
  
  TH1F *tauEnergy =MakeNormTH1F(20,0.8,1,Analyze,"TauJetPTResol.EnergieCen>>tauEnergy",1, 0, 1,2,false);
  tauEnergy->Draw();
  tauEnergy->SetTitle("");
  tauEnergy->GetYaxis()->SetTitle("Fraction of events");
  tauEnergy->GetXaxis()->SetTitle("C_{#tau}");
  
  
  TPaveText *Delphes1 = MakeTPave(0.3,0.85,0.45,0.9,"MG/ME + Delphes");
  Delphes1->Draw();
  TPaveText *ctau = MakeTPave(0.3,0.75,0.45,0.8,"C_{#tau} = #frac{#sum E^{towers} (#DeltaR = 0.15)}{E^{jet}}");
  ctau->Draw();
  TPaveText *events1 = MakeTPave(0.3,0.65,0.45,0.7,"Events: WHq'#rightarrow WWWq'#rightarrow lllq', m_{H}=150 GeV ");
  events1->Draw();
  
  
  TCanvas *ct2 = new TCanvas("ct2","Tau information",100,100,600,450);
  ct2->cd();
  TH1F *NumTrack =MakeNormTH1F(6,0,6,Analyze,"TauJetPTResol.NumTrack>>NumTrack",1, 0, 1,2,false);
  NumTrack->Draw();
  NumTrack->SetTitle("");
  NumTrack->GetYaxis()->SetTitle("Fraction of events");
  NumTrack->GetXaxis()->SetTitle("N^{tracks}");
  
  TPaveText *Delphes = MakeTPave(0.6,0.85,0.85,0.9,"MG/ME + Delphes");
  Delphes->Draw();
  TPaveText *numtracks = MakeTPave(0.6,0.75,0.85,0.8,"#DeltaR < 0.4, p_{T}^{track} > 2 GeV");
  numtracks->Draw();
  TPaveText *events = MakeTPave(0.6,0.65,0.85,0.7,"Events: WHq'#rightarrow WWWq'#rightarrow lllq', m_{H}=150 GeV ");
  events->Draw();
   
}

void ETmisResol()
{
  
  setTDRStyle();
  gROOT->Reset();
  
  //TFile *f1 = new TFile("JET2.root","read");
  TFile *f1 = new TFile("JET2_cms_midpoint.root","read");
  
  if(!f1->IsOpen()) { cout << "could not open "<< f1->GetName() << ". Exiting..." << endl; return;}
  if(!f1->FindKey("Analysis")) { cout << "Bad input file, could not find the \"Analysis\" tree. Exiting..." << endl; return;}
  TTree *Analyze = (TTree*)f1->Get("Analysis");
  
  TF1 *fitfun = new TF1("user","[0]*sqrt(x)",0,600);
  fitfun->SetLineColor(kBlack);
  fitfun->SetLineStyle(2);
  const Int_t numBin=6;
  double bins[numBin]={180,260,340,420,500,580};
  TProfile *ETSoverET = new TProfile("ETSoverET","ETmis resol",(numBin-1),bins,-1000,1000);
 
 
  double rms[numBin-1];
  
  TCanvas *c5 = new TCanvas("c5","PTmis resol",0,0,1000,650);
  c5->cd(); int frame=0;
  c5->Divide(6,2);
  
  double x[numBin];
  double y[numBin];
  
  for ( int i=0; i<(numBin-1); i++)  // première bin : i ==1 et pas i == 0
    {
      TAxis *xaxis = ETSoverET->GetXaxis();
      float binCenter = xaxis->GetBinCenter(i+1);
      int binMin = (int)xaxis->GetBinLowEdge(i+1);
      int binMax = (int)xaxis->GetBinUpEdge(i+1);
      char tempMin[500];
      sprintf(tempMin,"ETmisResol.SEt>%d",binMin);
      string mystringMin(tempMin);
      char tempMax[500];
      sprintf(tempMax,"ETmisResol.SEt<%d",binMax);
      string mystringMax(tempMax);
      
      char tempName[500];
      sprintf(tempName,"ETmisResol.ExSmeare>>hETSoverET%d",i);
      string mystringName(tempName);
      
      c5->cd(++frame);
      GaussValuesETmis(Analyze,tempName,rms[i],mystringMin,mystringMax);
      x[i]=binCenter;
      y[i]=rms[i];
      
    }
  
  TCanvas *c6 = new TCanvas("c6","ETmis resolution",100,100,600,450);
  c6->cd();

  TF1 *fdo = new TF1("fdo","0.6*sqrt(x)",1,600);
  TF1 *fup = new TF1("fup","0.7*sqrt(x)",1,600);
  int N = 100;
  float xx[N], yy[N], eex[N], eey[N];
  for (int i=0; i<N; i++) {
     xx[i]  = 6*i;
     yy[i]  = (fup->Eval(xx[i]) + fdo->Eval(xx[i]))/2.;
     eex[i] = 0;
     eey[i] = (fup->Eval(xx[i]) - fdo->Eval(xx[i]))/2.;
  }
  TGraphErrors *gr = new TGraphErrors(N,xx,yy,eex,eey);
  gr->SetFillColor(18);

  
  x[numBin]=0;
  y[numBin]=0;
  TGraph *gr11 = new TGraph(numBin,x,rms);
  gr11->SetTitle("");
  gr11->SetMarkerStyle(3);
  gr11->SetLineStyle(2);
  gr11->Fit("user","RQ");
  gr11->Fit("user","RQ");
  gr11->Fit("user","RQ");
  gr11->Fit("user","RQ");


  TMultiGraph *mgr = new TMultiGraph("mgr","");
  mgr->Add(gr,"3");
  mgr->Add(gr11,"P");
  mgr->Draw("A");
  mgr->GetXaxis()->SetTitle("#Sigma E_{T} [GeV]");
  mgr->GetYaxis()->SetTitle("Resolution of x-component  of MET [GeV]");
  mgr->GetYaxis()->SetRangeUser(0,60);
  mgr->GetXaxis()->SetRangeUser(1,600);
  mgr->SetMaximum(16);

  Double_t* params = fitfun->GetParameters(); 

  char tempResol[500];
  sprintf(tempResol,"E_{x}^{mis} resolution: %.2f #times #sqrt{E_{T}}",params[0]);

  TPaveText *leg1 = MakeTPave(0.26,0.84,0.43,0.89,tempResol);
  leg1->Draw();

  TPaveText *leg2 = MakeTPave(0.15,0.75,0.45,0.8,"Events: pp #rightarrow ggX");
  leg2->Draw();

  TPaveText *Delphes = MakeTPave(0.65,0.19,0.8,0.24,"MG/ME + Pythia + Delphes");
  Delphes->Draw();
 
  TPaveText *cms = MakeTPave(0.65,0.25,0.8,0.30,"CMS-like detector");
  cms->Draw();

  TLegend *legend = new TLegend(0.69,0.6,0.94,0.74,NULL,"NDC");
  legend->AddEntry(gr,"CMS","f");
  legend->AddEntry(gr11,"Delphes","l");
  legend->SetFillColor(10);
  legend->SetBorderSize(0);
  legend->Draw();

 
  delete fitfun;
}

void General()
{
  JetResol();
  ElecResol();
  ETmisResol();
  //TauJetInfo();
  
}


